gowin32

package module
v0.0.0-...-82c9bda Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

README

gowin32

This library provides wrappers to facilitate calling the Win32 API from Go. The wrappers package contains wrappers that directly expose certain portions of the Win32 API in Go, similar to what is provided by the syscall package in the Go runtime. The gowin32 package contains helper functions and data structures that encapsulate Win32 functionality in a more Go-friendly manner. Developers may elect to use either package or to combine both of them as they see fit.

This library is based on the Windows SDK 7.1.

Documentation

Rendered for windows/amd64

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AccountRightName

type AccountRightName string
const (
	AccountRightInteractiveLogon           AccountRightName = wrappers.SE_INTERACTIVE_LOGON_NAME
	AccountRightNetworkLogon               AccountRightName = wrappers.SE_NETWORK_LOGON_NAME
	AccountRightBatchLogon                 AccountRightName = wrappers.SE_BATCH_LOGON_NAME
	AccountRightServiceLogon               AccountRightName = wrappers.SE_SERVICE_LOGON_NAME
	AccountRightDenyInteractiveLogon       AccountRightName = wrappers.SE_DENY_INTERACTIVE_LOGON_NAME
	AccountRightDenyNetworkLogon           AccountRightName = wrappers.SE_DENY_NETWORK_LOGON_NAME
	AccountRightDenyBatchLogon             AccountRightName = wrappers.SE_DENY_BATCH_LOGON_NAME
	AccountRightDenyServiceLogon           AccountRightName = wrappers.SE_DENY_SERVICE_LOGON_NAME
	AccountRightRemoteInteractiveLogon     AccountRightName = wrappers.SE_REMOTE_INTERACTIVE_LOGON_NAME
	AccountRightDenyRemoteInteractiveLogon AccountRightName = wrappers.SE_DENY_REMOTE_INTERACTIVE_LOGON_NAME
)

type SecurityPolicy

type SecurityPolicy struct {
	// contains filtered or unexported fields
}

func OpenLocalSecurityPolicy

func OpenLocalSecurityPolicy() (*SecurityPolicy, error)

func (*SecurityPolicy) AddAccountRight

func (self *SecurityPolicy) AddAccountRight(sid *windows.SID, right AccountRightName) error

func (*SecurityPolicy) Close

func (self *SecurityPolicy) Close() error

type SidType

type SidType int32

see windows.SidType*

func GetLocalAccountByName

func GetLocalAccountByName(accountName string) (*windows.SID, string, SidType, error)

Directories

Path Synopsis
internal

Jump to